@@ -51,7 +51,7 @@ def clean_text(text):
 def count_words(input_file):
     """Count words in a text file.
 
-    Words are made lowercase and punctuation is removed 
+    Words are made lowercase and punctuation is removed
     before counting.
 
     Parameters
@@ -72,3 +72,9 @@ def count_words(input_file):
     text = clean_text(text)
     words = text.split()
     return Counter(words)
+
+
+def err():
+    a = 1
+    if a != 2:
+        raise (ValueError("You are great"))
